<?php

require_once('admin_options.php');
add_action('admin_menu', 'ncewpf_init');

$ncewpf_uninstall_opt = '_site_' . sha1(ncewpf_product_info('item_name'));
if (get_option($ncewpf_uninstall_opt) == 1) {
    $ncewpf_install_text = 'Re-Install';
} else {
    $ncewpf_install_text = 'Uninstall';
}

$ncewpf_admin_menus = array(
    array(
        'page_type' => 'top_level',
        'page_title' => 'Extend WordPress',
        'menu_title' => 'Extend WP FREE',
        'page_slug' => ncewpf_product_info('settings_page_slug'),
        'permission' => '"manage_opitons"',
        'callback_function' => 'ncewpf_item_info',
        'icon_url' => ncewpf_product_info('assets_url').'/images/menu_icon.png', // Can be used with top_level only
    ),
    
    array(
        'page_type' => 'sub_level',
        'page_title' => 'Documentation',
        'menu_title' => 'Documentation',
        'page_slug' => 'ncewpf_docs',
        'permission' => '"manage_opitons"',
        'callback_function' => 'ncewpf_docs',
        'icon_url' => '', // Can be used with top_level only
    ),
    
    array(
        'page_type' => 'sub_level',
        'page_title' => $ncewpf_install_text,
        'menu_title' => $ncewpf_install_text,
        'page_slug' => 'ncewpf_uninstall',
        'permission' => '"manage_opitons"',
        'callback_function' => 'ncewpf_uninstall',
        'icon_url' => '', // Can be used with top_level only
    ),
);

function ncewpf_docs() {
    global $ncewpf_options;
    ncewpf_display_options($ncewpf_options['documentation'], 'false');
}

function ncewpf_item_info() {
    global $ncewpf_options;
    ncewpf_display_options($ncewpf_options['info_page'], 'false');
}

function ncewpf_uninstall() {
    ncewpf_display_uninstall();
}

######################################################################
# PLUGIN INIT
######################################################################

function ncewpf_init() {
    global $ncewpf_admin_menus, $ncewpf_uninstall_opt;
    foreach ($ncewpf_admin_menus as $admin_page) {
        if ($admin_page['page_type'] == 'top_level') {
            $menu_page = add_menu_page($admin_page['page_title'], $admin_page['menu_title'], 'manage_options', $admin_page['page_slug'], $admin_page['callback_function'], $icon_url = $admin_page['icon_url']);
            add_action('admin_print_scripts', 'ncewpf_admin_scripts');
            add_action('admin_print_styles', 'ncewpf_admin_styles');
        } else {
            $menu_page = add_submenu_page(ncewpf_product_info('settings_page_slug'), $admin_page['page_title'], $admin_page['menu_title'], 'manage_options', $admin_page['page_slug'], $admin_page['callback_function']);
            add_action('admin_print_scripts', 'ncewpf_admin_scripts');
            add_action('admin_print_styles', 'ncewpf_admin_styles');
        }
    }

    // SETUP DATABASE
    if (get_option($ncewpf_uninstall_opt) == 1) {

        foreach ($ncewpf_admin_menus as $key => $value) {
            if ($_GET['page'] == $value['page_slug']) {
                if ($_GET['page'] != 'ncewpf_uninstall') {
                    $location = site_url('wp-admin/admin.php?page=ncewpf_uninstall');
                    wp_redirect($location);
                }
            }
        }
    } else {
        add_action('admin_head', 'ncewpf_install_db');
    }



    // REMOVE FIRST LINK IN ADMIN PAGES MENU
    add_action('admin_head', 'ncewpf_menu_fix');

    function ncewpf_menu_fix() {
        echo '<style type="text/css">ul#adminmenu li.toplevel_page_' . ncewpf_product_info('settings_page_slug') . ' .wp-first-item{display:none !important;} </style>';
    }

}

######################################################################
# UPGRADE CHECK
######################################################################

if (isset($_GET['nc_upgrade']) && $_GET['nc_upgrade'] == 'available') {
    $ncewpf_msg = '<span class="fw-message-info">' . __(sprintf('New version is available to download! <a target="_blank" href="%s" class="button-secondary" title="">Download Now</a>', 'http://www.netchillies.com/my-purchases'), 'ncewpf') . '</span>';
} elseif (isset($_GET['nc_upgrade']) && $_GET['nc_upgrade'] == 'na') {
    $ncewpf_msg = '<span class="fw-message-success fade">' . __(sprintf('You are using the latest version of %s', ncewpf_product_info('item_name'))) . '</span>';
}